@@ -10,22 +10,36 @@
 //! # Feature Detection and Description
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
-	pub use { super::CUDA_DescriptorMatcher, super::CUDA_Feature2DAsync, super::CUDA_FastFeatureDetector, super::CUDA_ORB };
+	pub use { super::CUDA_DescriptorMatcherConst, super::CUDA_DescriptorMatcher, super::CUDA_Feature2DAsyncConst, super::CUDA_Feature2DAsync, super::CUDA_FastFeatureDetectorConst, super::CUDA_FastFeatureDetector, super::CUDA_ORBConst, super::CUDA_ORB };
 }
 
 /// Abstract base class for matching keypoint descriptors.
 /// 
 /// It has two groups of match methods: for matching descriptors of an image with another image or with
 /// an image set.
-pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
+pub trait CUDA_DescriptorMatcherConst: core::AlgorithmTraitConst {
 	fn as_raw_CUDA_DescriptorMatcher(&self) -> *const c_void;
-	fn as_raw_mut_CUDA_DescriptorMatcher(&mut self) -> *mut c_void;
 
 	/// Returns true if the descriptor matcher supports masking permissible matches.
 	fn is_mask_supported(&self) -> Result<bool> {
 		unsafe { sys::cv_cuda_DescriptorMatcher_isMaskSupported_const(self.as_raw_CUDA_DescriptorMatcher()) }.into_result()
 	}
 	
+	/// Returns a constant link to the train descriptor collection.
+	fn get_train_descriptors(&self) -> Result<core::Vector<core::GpuMat>> {
+		unsafe { sys::cv_cuda_DescriptorMatcher_getTrainDescriptors_const(self.as_raw_CUDA_DescriptorMatcher()) }.into_result().map(|r| unsafe { core::Vector::<core::GpuMat>::opencv_from_extern(r) } )
+	}
+	
+	/// Returns true if there are no train descriptors in the collection.
+	fn empty(&self) -> Result<bool> {
+		unsafe { sys::cv_cuda_DescriptorMatcher_empty_const(self.as_raw_CUDA_DescriptorMatcher()) }.into_result()
+	}
+	
+}
+
+pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait + crate::cudafeatures2d::CUDA_DescriptorMatcherConst {
+	fn as_raw_mut_CUDA_DescriptorMatcher(&mut self) -> *mut c_void;
+
 	/// Adds descriptors to train a descriptor collection.
 	/// 
 	/// If the collection is not empty, the new descriptors are added to existing train descriptors.
@@ -33,25 +47,15 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## Parameters
 	/// * descriptors: Descriptors to add. Each descriptors[i] is a set of descriptors from the same
 	/// train image.
-	fn add(&mut self, descriptors: &core::Vector::<core::GpuMat>) -> Result<()> {
+	fn add(&mut self, descriptors: &core::Vector<core::GpuMat>) -> Result<()> {
 		unsafe { sys::cv_cuda_DescriptorMatcher_add_const_vector_GpuMat_R(self.as_raw_mut_CUDA_DescriptorMatcher(), descriptors.as_raw_VectorOfGpuMat()) }.into_result()
 	}
 	
-	/// Returns a constant link to the train descriptor collection.
-	fn get_train_descriptors(&self) -> Result<core::Vector::<core::GpuMat>> {
-		unsafe { sys::cv_cuda_DescriptorMatcher_getTrainDescriptors_const(self.as_raw_CUDA_DescriptorMatcher()) }.into_result().map(|r| unsafe { core::Vector::<core::GpuMat>::opencv_from_extern(r) } )
-	}
-	
 	/// Clears the train descriptor collection.
 	fn clear(&mut self) -> Result<()> {
 		unsafe { sys::cv_cuda_DescriptorMatcher_clear(self.as_raw_mut_CUDA_DescriptorMatcher()) }.into_result()
 	}
 	
-	/// Returns true if there are no train descriptors in the collection.
-	fn empty(&self) -> Result<bool> {
-		unsafe { sys::cv_cuda_DescriptorMatcher_empty_const(self.as_raw_CUDA_DescriptorMatcher()) }.into_result()
-	}
-	
 	/// Trains a descriptor matcher.
 	/// 
 	/// Trains a descriptor matcher (for example, the flann index). In all methods to match, the method
@@ -79,7 +83,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// 
 	/// ## C++ default parameters
 	/// * mask: noArray()
-	fn match_(&mut self, query_descriptors: &dyn core::ToInputArray, train_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector::<core::DMatch>, mask: &dyn core::ToInputArray) -> Result<()> {
+	fn match_(&mut self, query_descriptors: &dyn core::ToInputArray, train_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector<core::DMatch>, mask: &dyn core::ToInputArray) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		input_array_arg!(train_descriptors);
 		input_array_arg!(mask);
@@ -107,7 +111,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// 
 	/// ## C++ default parameters
 	/// * masks: std::vector<GpuMat>()
-	fn match__1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector::<core::DMatch>, masks: &core::Vector::<core::GpuMat>) -> Result<()> {
+	fn match__1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector<core::DMatch>, masks: &core::Vector<core::GpuMat>) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		unsafe { sys::cv_cuda_DescriptorMatcher_match_const__InputArrayR_vector_DMatch_R_const_vector_GpuMat_R(self.as_raw_mut_CUDA_DescriptorMatcher(), query_descriptors.as_raw__InputArray(), matches.as_raw_mut_VectorOfDMatch(), masks.as_raw_VectorOfGpuMat()) }.into_result()
 	}
@@ -164,7 +168,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * masks: std::vector<GpuMat>()
 	/// * stream: Stream::Null()
-	fn match_async_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut dyn core::ToOutputArray, masks: &core::Vector::<core::GpuMat>, stream: &mut core::Stream) -> Result<()> {
+	fn match_async_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut dyn core::ToOutputArray, masks: &core::Vector<core::GpuMat>, stream: &mut core::Stream) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		output_array_arg!(matches);
 		unsafe { sys::cv_cuda_DescriptorMatcher_matchAsync_const__InputArrayR_const__OutputArrayR_const_vector_GpuMat_R_StreamR(self.as_raw_mut_CUDA_DescriptorMatcher(), query_descriptors.as_raw__InputArray(), matches.as_raw__OutputArray(), masks.as_raw_VectorOfGpuMat(), stream.as_raw_mut_Stream()) }.into_result()
@@ -178,7 +182,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## Parameters
 	/// * gpu_matches: Matches, returned from DescriptorMatcher::matchAsync.
 	/// * matches: Vector of DMatch objects.
-	fn match_convert(&mut self, gpu_matches: &dyn core::ToInputArray, matches: &mut core::Vector::<core::DMatch>) -> Result<()> {
+	fn match_convert(&mut self, gpu_matches: &dyn core::ToInputArray, matches: &mut core::Vector<core::DMatch>) -> Result<()> {
 		input_array_arg!(gpu_matches);
 		unsafe { sys::cv_cuda_DescriptorMatcher_matchConvert_const__InputArrayR_vector_DMatch_R(self.as_raw_mut_CUDA_DescriptorMatcher(), gpu_matches.as_raw__InputArray(), matches.as_raw_mut_VectorOfDMatch()) }.into_result()
 	}
@@ -205,7 +209,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * mask: noArray()
 	/// * compact_result: false
-	fn knn_match(&mut self, query_descriptors: &dyn core::ToInputArray, train_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector::<core::Vector::<core::DMatch>>, k: i32, mask: &dyn core::ToInputArray, compact_result: bool) -> Result<()> {
+	fn knn_match(&mut self, query_descriptors: &dyn core::ToInputArray, train_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector<core::Vector<core::DMatch>>, k: i32, mask: &dyn core::ToInputArray, compact_result: bool) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		input_array_arg!(train_descriptors);
 		input_array_arg!(mask);
@@ -236,7 +240,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * masks: std::vector<GpuMat>()
 	/// * compact_result: false
-	fn knn_match_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector::<core::Vector::<core::DMatch>>, k: i32, masks: &core::Vector::<core::GpuMat>, compact_result: bool) -> Result<()> {
+	fn knn_match_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector<core::Vector<core::DMatch>>, k: i32, masks: &core::Vector<core::GpuMat>, compact_result: bool) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		unsafe { sys::cv_cuda_DescriptorMatcher_knnMatch_const__InputArrayR_vector_vector_DMatch__R_int_const_vector_GpuMat_R_bool(self.as_raw_mut_CUDA_DescriptorMatcher(), query_descriptors.as_raw__InputArray(), matches.as_raw_mut_VectorOfVectorOfDMatch(), k, masks.as_raw_VectorOfGpuMat(), compact_result) }.into_result()
 	}
@@ -293,7 +297,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * masks: std::vector<GpuMat>()
 	/// * stream: Stream::Null()
-	fn knn_match_async_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut dyn core::ToOutputArray, k: i32, masks: &core::Vector::<core::GpuMat>, stream: &mut core::Stream) -> Result<()> {
+	fn knn_match_async_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut dyn core::ToOutputArray, k: i32, masks: &core::Vector<core::GpuMat>, stream: &mut core::Stream) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		output_array_arg!(matches);
 		unsafe { sys::cv_cuda_DescriptorMatcher_knnMatchAsync_const__InputArrayR_const__OutputArrayR_int_const_vector_GpuMat_R_StreamR(self.as_raw_mut_CUDA_DescriptorMatcher(), query_descriptors.as_raw__InputArray(), matches.as_raw__OutputArray(), k, masks.as_raw_VectorOfGpuMat(), stream.as_raw_mut_Stream()) }.into_result()
@@ -313,7 +317,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// 
 	/// ## C++ default parameters
 	/// * compact_result: false
-	fn knn_match_convert(&mut self, gpu_matches: &dyn core::ToInputArray, matches: &mut core::Vector::<core::Vector::<core::DMatch>>, compact_result: bool) -> Result<()> {
+	fn knn_match_convert(&mut self, gpu_matches: &dyn core::ToInputArray, matches: &mut core::Vector<core::Vector<core::DMatch>>, compact_result: bool) -> Result<()> {
 		input_array_arg!(gpu_matches);
 		unsafe { sys::cv_cuda_DescriptorMatcher_knnMatchConvert_const__InputArrayR_vector_vector_DMatch__R_bool(self.as_raw_mut_CUDA_DescriptorMatcher(), gpu_matches.as_raw__InputArray(), matches.as_raw_mut_VectorOfVectorOfDMatch(), compact_result) }.into_result()
 	}
@@ -341,7 +345,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * mask: noArray()
 	/// * compact_result: false
-	fn radius_match(&mut self, query_descriptors: &dyn core::ToInputArray, train_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector::<core::Vector::<core::DMatch>>, max_distance: f32, mask: &dyn core::ToInputArray, compact_result: bool) -> Result<()> {
+	fn radius_match(&mut self, query_descriptors: &dyn core::ToInputArray, train_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector<core::Vector<core::DMatch>>, max_distance: f32, mask: &dyn core::ToInputArray, compact_result: bool) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		input_array_arg!(train_descriptors);
 		input_array_arg!(mask);
@@ -373,7 +377,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * masks: std::vector<GpuMat>()
 	/// * compact_result: false
-	fn radius_match_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector::<core::Vector::<core::DMatch>>, max_distance: f32, masks: &core::Vector::<core::GpuMat>, compact_result: bool) -> Result<()> {
+	fn radius_match_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut core::Vector<core::Vector<core::DMatch>>, max_distance: f32, masks: &core::Vector<core::GpuMat>, compact_result: bool) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		unsafe { sys::cv_cuda_DescriptorMatcher_radiusMatch_const__InputArrayR_vector_vector_DMatch__R_float_const_vector_GpuMat_R_bool(self.as_raw_mut_CUDA_DescriptorMatcher(), query_descriptors.as_raw__InputArray(), matches.as_raw_mut_VectorOfVectorOfDMatch(), max_distance, masks.as_raw_VectorOfGpuMat(), compact_result) }.into_result()
 	}
@@ -432,7 +436,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// ## C++ default parameters
 	/// * masks: std::vector<GpuMat>()
 	/// * stream: Stream::Null()
-	fn radius_match_async_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut dyn core::ToOutputArray, max_distance: f32, masks: &core::Vector::<core::GpuMat>, stream: &mut core::Stream) -> Result<()> {
+	fn radius_match_async_1(&mut self, query_descriptors: &dyn core::ToInputArray, matches: &mut dyn core::ToOutputArray, max_distance: f32, masks: &core::Vector<core::GpuMat>, stream: &mut core::Stream) -> Result<()> {
 		input_array_arg!(query_descriptors);
 		output_array_arg!(matches);
 		unsafe { sys::cv_cuda_DescriptorMatcher_radiusMatchAsync_const__InputArrayR_const__OutputArrayR_float_const_vector_GpuMat_R_StreamR(self.as_raw_mut_CUDA_DescriptorMatcher(), query_descriptors.as_raw__InputArray(), matches.as_raw__OutputArray(), max_distance, masks.as_raw_VectorOfGpuMat(), stream.as_raw_mut_Stream()) }.into_result()
@@ -452,7 +456,7 @@ pub trait CUDA_DescriptorMatcher: core::AlgorithmTrait {
 	/// 
 	/// ## C++ default parameters
 	/// * compact_result: false
-	fn radius_match_convert(&mut self, gpu_matches: &dyn core::ToInputArray, matches: &mut core::Vector::<core::Vector::<core::DMatch>>, compact_result: bool) -> Result<()> {
+	fn radius_match_convert(&mut self, gpu_matches: &dyn core::ToInputArray, matches: &mut core::Vector<core::Vector<core::DMatch>>, compact_result: bool) -> Result<()> {
 		input_array_arg!(gpu_matches);
 		unsafe { sys::cv_cuda_DescriptorMatcher_radiusMatchConvert_const__InputArrayR_vector_vector_DMatch__R_bool(self.as_raw_mut_CUDA_DescriptorMatcher(), gpu_matches.as_raw__InputArray(), matches.as_raw_mut_VectorOfVectorOfDMatch(), compact_result) }.into_result()
 	}
@@ -473,14 +477,22 @@ impl dyn CUDA_DescriptorMatcher + '_ {
 	/// 
 	/// ## C++ default parameters
 	/// * norm_type: cv::NORM_L2
-	pub fn create_bf_matcher(norm_type: i32) -> Result<core::Ptr::<dyn crate::cudafeatures2d::CUDA_DescriptorMatcher>> {
+	pub fn create_bf_matcher(norm_type: i32) -> Result<core::Ptr<dyn crate::cudafeatures2d::CUDA_DescriptorMatcher>> {
 		unsafe { sys::cv_cuda_DescriptorMatcher_createBFMatcher_int(norm_type) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafeatures2d::CUDA_DescriptorMatcher>::opencv_from_extern(r) } )
 	}
 	
 }
 /// Wrapping class for feature detection using the FAST method.
-pub trait CUDA_FastFeatureDetector: crate::cudafeatures2d::CUDA_Feature2DAsync {
+pub trait CUDA_FastFeatureDetectorConst: crate::cudafeatures2d::CUDA_Feature2DAsyncConst {
 	fn as_raw_CUDA_FastFeatureDetector(&self) -> *const c_void;
+
+	fn get_max_num_points(&self) -> Result<i32> {
+		unsafe { sys::cv_cuda_FastFeatureDetector_getMaxNumPoints_const(self.as_raw_CUDA_FastFeatureDetector()) }.into_result()
+	}
+	
+}
+
+pub trait CUDA_FastFeatureDetector: crate::cudafeatures2d::CUDA_FastFeatureDetectorConst + crate::cudafeatures2d::CUDA_Feature2DAsync {
 	fn as_raw_mut_CUDA_FastFeatureDetector(&mut self) -> *mut c_void;
 
 	fn set_threshold(&mut self, threshold: i32) -> Result<()> {
@@ -491,10 +503,6 @@ pub trait CUDA_FastFeatureDetector: crate::cudafeatures2d::CUDA_Feature2DAsync {
 		unsafe { sys::cv_cuda_FastFeatureDetector_setMaxNumPoints_int(self.as_raw_mut_CUDA_FastFeatureDetector(), max_npoints) }.into_result()
 	}
 	
-	fn get_max_num_points(&self) -> Result<i32> {
-		unsafe { sys::cv_cuda_FastFeatureDetector_getMaxNumPoints_const(self.as_raw_CUDA_FastFeatureDetector()) }.into_result()
-	}
-	
 }
 
 impl dyn CUDA_FastFeatureDetector + '_ {
@@ -507,14 +515,18 @@ impl dyn CUDA_FastFeatureDetector + '_ {
 	/// * nonmax_suppression: true
 	/// * typ: cv::FastFeatureDetector::TYPE_9_16
 	/// * max_npoints: 5000
-	pub fn create(threshold: i32, nonmax_suppression: bool, typ: i32, max_npoints: i32) -> Result<core::Ptr::<dyn crate::cudafeatures2d::CUDA_FastFeatureDetector>> {
+	pub fn create(threshold: i32, nonmax_suppression: bool, typ: i32, max_npoints: i32) -> Result<core::Ptr<dyn crate::cudafeatures2d::CUDA_FastFeatureDetector>> {
 		unsafe { sys::cv_cuda_FastFeatureDetector_create_int_bool_int_int(threshold, nonmax_suppression, typ, max_npoints) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafeatures2d::CUDA_FastFeatureDetector>::opencv_from_extern(r) } )
 	}
 	
 }
 /// Abstract base class for CUDA asynchronous 2D image feature detectors and descriptor extractors.
-pub trait CUDA_Feature2DAsync: crate::features2d::Feature2DTrait {
+pub trait CUDA_Feature2DAsyncConst: crate::features2d::Feature2DTraitConst {
 	fn as_raw_CUDA_Feature2DAsync(&self) -> *const c_void;
+
+}
+
+pub trait CUDA_Feature2DAsync: crate::cudafeatures2d::CUDA_Feature2DAsyncConst + crate::features2d::Feature2DTrait {
 	fn as_raw_mut_CUDA_Feature2DAsync(&mut self) -> *mut c_void;
 
 	/// Detects keypoints in an image.
@@ -567,7 +579,7 @@ pub trait CUDA_Feature2DAsync: crate::features2d::Feature2DTrait {
 	}
 	
 	/// Converts keypoints array from internal representation to standard vector.
-	fn convert(&mut self, gpu_keypoints: &dyn core::ToInputArray, keypoints: &mut core::Vector::<core::KeyPoint>) -> Result<()> {
+	fn convert(&mut self, gpu_keypoints: &dyn core::ToInputArray, keypoints: &mut core::Vector<core::KeyPoint>) -> Result<()> {
 		input_array_arg!(gpu_keypoints);
 		unsafe { sys::cv_cuda_Feature2DAsync_convert_const__InputArrayR_vector_KeyPoint_R(self.as_raw_mut_CUDA_Feature2DAsync(), gpu_keypoints.as_raw__InputArray(), keypoints.as_raw_mut_VectorOfKeyPoint()) }.into_result()
 	}
@@ -577,8 +589,20 @@ pub trait CUDA_Feature2DAsync: crate::features2d::Feature2DTrait {
 /// Class implementing the ORB (*oriented BRIEF*) keypoint detector and descriptor extractor
 /// ## See also
 /// cv::ORB
-pub trait CUDA_ORB: crate::cudafeatures2d::CUDA_Feature2DAsync {
+pub trait CUDA_ORBConst: crate::cudafeatures2d::CUDA_Feature2DAsyncConst {
 	fn as_raw_CUDA_ORB(&self) -> *const c_void;
+
+	fn get_blur_for_descriptor(&self) -> Result<bool> {
+		unsafe { sys::cv_cuda_ORB_getBlurForDescriptor_const(self.as_raw_CUDA_ORB()) }.into_result()
+	}
+	
+	fn get_fast_threshold(&self) -> Result<i32> {
+		unsafe { sys::cv_cuda_ORB_getFastThreshold_const(self.as_raw_CUDA_ORB()) }.into_result()
+	}
+	
+}
+
+pub trait CUDA_ORB: crate::cudafeatures2d::CUDA_Feature2DAsync + crate::cudafeatures2d::CUDA_ORBConst {
 	fn as_raw_mut_CUDA_ORB(&mut self) -> *mut c_void;
 
 	/// if true, image will be blurred before descriptors calculation
@@ -586,18 +610,10 @@ pub trait CUDA_ORB: crate::cudafeatures2d::CUDA_Feature2DAsync {
 		unsafe { sys::cv_cuda_ORB_setBlurForDescriptor_bool(self.as_raw_mut_CUDA_ORB(), blur_for_descriptor) }.into_result()
 	}
 	
-	fn get_blur_for_descriptor(&self) -> Result<bool> {
-		unsafe { sys::cv_cuda_ORB_getBlurForDescriptor_const(self.as_raw_CUDA_ORB()) }.into_result()
-	}
-	
 	fn set_fast_threshold(&mut self, fast_threshold: i32) -> Result<()> {
 		unsafe { sys::cv_cuda_ORB_setFastThreshold_int(self.as_raw_mut_CUDA_ORB(), fast_threshold) }.into_result()
 	}
 	
-	fn get_fast_threshold(&self) -> Result<i32> {
-		unsafe { sys::cv_cuda_ORB_getFastThreshold_const(self.as_raw_CUDA_ORB()) }.into_result()
-	}
-	
 }
 
 impl dyn CUDA_ORB + '_ {
@@ -619,7 +635,7 @@ impl dyn CUDA_ORB + '_ {
 	/// * patch_size: 31
 	/// * fast_threshold: 20
 	/// * blur_for_descriptor: false
-	pub fn create(nfeatures: i32, scale_factor: f32, nlevels: i32, edge_threshold: i32, first_level: i32, wta_k: i32, score_type: i32, patch_size: i32, fast_threshold: i32, blur_for_descriptor: bool) -> Result<core::Ptr::<dyn crate::cudafeatures2d::CUDA_ORB>> {
+	pub fn create(nfeatures: i32, scale_factor: f32, nlevels: i32, edge_threshold: i32, first_level: i32, wta_k: i32, score_type: i32, patch_size: i32, fast_threshold: i32, blur_for_descriptor: bool) -> Result<core::Ptr<dyn crate::cudafeatures2d::CUDA_ORB>> {
 		unsafe { sys::cv_cuda_ORB_create_int_float_int_int_int_int_int_int_int_bool(nfeatures, scale_factor, nlevels, edge_threshold, first_level, wta_k, score_type, patch_size, fast_threshold, blur_for_descriptor) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafeatures2d::CUDA_ORB>::opencv_from_extern(r) } )
 	}
 	
