@@ -68,7 +68,7 @@
 //! Tham Ngap Wei, thamngapwei@gmail.com
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
-	pub use { super::ImgHashBaseTrait, super::AverageHashTrait, super::BlockMeanHashTrait, super::ColorMomentHashTrait, super::MarrHildrethHashTrait, super::PHashTrait, super::RadialVarianceHashTrait };
+	pub use { super::ImgHashBaseTraitConst, super::ImgHashBaseTrait, super::AverageHashTraitConst, super::AverageHashTrait, super::BlockMeanHashTraitConst, super::BlockMeanHashTrait, super::ColorMomentHashTraitConst, super::ColorMomentHashTrait, super::MarrHildrethHashTraitConst, super::MarrHildrethHashTrait, super::PHashTraitConst, super::PHashTrait, super::RadialVarianceHashTraitConst, super::RadialVarianceHashTrait };
 }
 
 /// use fewer block and generate 16*16/8 uchar hash value
@@ -173,8 +173,12 @@ pub fn radial_variance_hash(input_arr: &dyn core::ToInputArray, output_arr: &mut
 /// 
 /// This is a fast image hashing algorithm, but only work on simple case. For more details, please
 /// refer to [lookslikeit](https://docs.opencv.org/4.5.3/d0/de3/citelist.html#CITEREF_lookslikeit)
-pub trait AverageHashTrait: crate::img_hash::ImgHashBaseTrait {
+pub trait AverageHashTraitConst: crate::img_hash::ImgHashBaseTraitConst {
 	fn as_raw_AverageHash(&self) -> *const c_void;
+
+}
+
+pub trait AverageHashTrait: crate::img_hash::AverageHashTraitConst + crate::img_hash::ImgHashBaseTrait {
 	fn as_raw_mut_AverageHash(&mut self) -> *mut c_void;
 
 }
@@ -196,30 +200,34 @@ impl Drop for AverageHash {
 	}
 }
 
-impl AverageHash {
-	#[inline] pub fn as_raw_AverageHash(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_AverageHash(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for AverageHash {}
 
-impl core::AlgorithmTrait for AverageHash {
+impl core::AlgorithmTraitConst for AverageHash {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for AverageHash {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for AverageHash {
+impl crate::img_hash::ImgHashBaseTraitConst for AverageHash {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for AverageHash {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::AverageHashTrait for AverageHash {
+impl crate::img_hash::AverageHashTraitConst for AverageHash {
 	#[inline] fn as_raw_AverageHash(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::AverageHashTrait for AverageHash {
 	#[inline] fn as_raw_mut_AverageHash(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
 impl AverageHash {
-	pub fn create() -> Result<core::Ptr::<crate::img_hash::AverageHash>> {
+	pub fn create() -> Result<core::Ptr<crate::img_hash::AverageHash>> {
 		unsafe { sys::cv_img_hash_AverageHash_create() }.into_result().map(|r| unsafe { core::Ptr::<crate::img_hash::AverageHash>::opencv_from_extern(r) } )
 	}
 	
@@ -232,8 +240,16 @@ boxed_cast_base! { AverageHash, crate::img_hash::ImgHashBase, cv_AverageHash_to_
 /// Image hash based on block mean.
 /// 
 /// See [zauner2010implementation](https://docs.opencv.org/4.5.3/d0/de3/citelist.html#CITEREF_zauner2010implementation) for details.
-pub trait BlockMeanHashTrait: crate::img_hash::ImgHashBaseTrait {
+pub trait BlockMeanHashTraitConst: crate::img_hash::ImgHashBaseTraitConst {
 	fn as_raw_BlockMeanHash(&self) -> *const c_void;
+
+	fn get_mean(&self) -> Result<core::Vector<f64>> {
+		unsafe { sys::cv_img_hash_BlockMeanHash_getMean_const(self.as_raw_BlockMeanHash()) }.into_result().map(|r| unsafe { core::Vector::<f64>::opencv_from_extern(r) } )
+	}
+	
+}
+
+pub trait BlockMeanHashTrait: crate::img_hash::BlockMeanHashTraitConst + crate::img_hash::ImgHashBaseTrait {
 	fn as_raw_mut_BlockMeanHash(&mut self) -> *mut c_void;
 
 	/// Create BlockMeanHash object
@@ -243,10 +259,6 @@ pub trait BlockMeanHashTrait: crate::img_hash::ImgHashBaseTrait {
 		unsafe { sys::cv_img_hash_BlockMeanHash_setMode_int(self.as_raw_mut_BlockMeanHash(), mode) }.into_result()
 	}
 	
-	fn get_mean(&self) -> Result<core::Vector::<f64>> {
-		unsafe { sys::cv_img_hash_BlockMeanHash_getMean_const(self.as_raw_BlockMeanHash()) }.into_result().map(|r| unsafe { core::Vector::<f64>::opencv_from_extern(r) } )
-	}
-	
 }
 
 /// Image hash based on block mean.
@@ -265,32 +277,36 @@ impl Drop for BlockMeanHash {
 	}
 }
 
-impl BlockMeanHash {
-	#[inline] pub fn as_raw_BlockMeanHash(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_BlockMeanHash(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for BlockMeanHash {}
 
-impl core::AlgorithmTrait for BlockMeanHash {
+impl core::AlgorithmTraitConst for BlockMeanHash {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for BlockMeanHash {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for BlockMeanHash {
+impl crate::img_hash::ImgHashBaseTraitConst for BlockMeanHash {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for BlockMeanHash {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::BlockMeanHashTrait for BlockMeanHash {
+impl crate::img_hash::BlockMeanHashTraitConst for BlockMeanHash {
 	#[inline] fn as_raw_BlockMeanHash(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::BlockMeanHashTrait for BlockMeanHash {
 	#[inline] fn as_raw_mut_BlockMeanHash(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
 impl BlockMeanHash {
 	/// ## C++ default parameters
 	/// * mode: BLOCK_MEAN_HASH_MODE_0
-	pub fn create(mode: i32) -> Result<core::Ptr::<crate::img_hash::BlockMeanHash>> {
+	pub fn create(mode: i32) -> Result<core::Ptr<crate::img_hash::BlockMeanHash>> {
 		unsafe { sys::cv_img_hash_BlockMeanHash_create_int(mode) }.into_result().map(|r| unsafe { core::Ptr::<crate::img_hash::BlockMeanHash>::opencv_from_extern(r) } )
 	}
 	
@@ -303,8 +319,12 @@ boxed_cast_base! { BlockMeanHash, crate::img_hash::ImgHashBase, cv_BlockMeanHash
 /// Image hash based on color moments.
 /// 
 /// See [tang2012perceptual](https://docs.opencv.org/4.5.3/d0/de3/citelist.html#CITEREF_tang2012perceptual) for details.
-pub trait ColorMomentHashTrait: crate::img_hash::ImgHashBaseTrait {
+pub trait ColorMomentHashTraitConst: crate::img_hash::ImgHashBaseTraitConst {
 	fn as_raw_ColorMomentHash(&self) -> *const c_void;
+
+}
+
+pub trait ColorMomentHashTrait: crate::img_hash::ColorMomentHashTraitConst + crate::img_hash::ImgHashBaseTrait {
 	fn as_raw_mut_ColorMomentHash(&mut self) -> *mut c_void;
 
 }
@@ -325,30 +345,34 @@ impl Drop for ColorMomentHash {
 	}
 }
 
-impl ColorMomentHash {
-	#[inline] pub fn as_raw_ColorMomentHash(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_ColorMomentHash(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for ColorMomentHash {}
 
-impl core::AlgorithmTrait for ColorMomentHash {
+impl core::AlgorithmTraitConst for ColorMomentHash {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for ColorMomentHash {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for ColorMomentHash {
+impl crate::img_hash::ImgHashBaseTraitConst for ColorMomentHash {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for ColorMomentHash {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ColorMomentHashTrait for ColorMomentHash {
+impl crate::img_hash::ColorMomentHashTraitConst for ColorMomentHash {
 	#[inline] fn as_raw_ColorMomentHash(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ColorMomentHashTrait for ColorMomentHash {
 	#[inline] fn as_raw_mut_ColorMomentHash(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
 impl ColorMomentHash {
-	pub fn create() -> Result<core::Ptr::<crate::img_hash::ColorMomentHash>> {
+	pub fn create() -> Result<core::Ptr<crate::img_hash::ColorMomentHash>> {
 		unsafe { sys::cv_img_hash_ColorMomentHash_create() }.into_result().map(|r| unsafe { core::Ptr::<crate::img_hash::ColorMomentHash>::opencv_from_extern(r) } )
 	}
 	
@@ -359,20 +383,9 @@ boxed_cast_base! { ColorMomentHash, core::Algorithm, cv_ColorMomentHash_to_Algor
 boxed_cast_base! { ColorMomentHash, crate::img_hash::ImgHashBase, cv_ColorMomentHash_to_ImgHashBase }
 
 /// The base class for image hash algorithms
-pub trait ImgHashBaseTrait: core::AlgorithmTrait {
+pub trait ImgHashBaseTraitConst: core::AlgorithmTraitConst {
 	fn as_raw_ImgHashBase(&self) -> *const c_void;
-	fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void;
 
-	/// Computes hash of the input image
-	/// ## Parameters
-	/// * inputArr: input image want to compute hash value
-	/// * outputArr: hash of the image
-	fn compute(&mut self, input_arr: &dyn core::ToInputArray, output_arr: &mut dyn core::ToOutputArray) -> Result<()> {
-		input_array_arg!(input_arr);
-		output_array_arg!(output_arr);
-		unsafe { sys::cv_img_hash_ImgHashBase_compute_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ImgHashBase(), input_arr.as_raw__InputArray(), output_arr.as_raw__OutputArray()) }.into_result()
-	}
-	
 	/// Compare the hash value between inOne and inTwo
 	/// ## Parameters
 	/// * hashOne: Hash value one
@@ -388,6 +401,21 @@ pub trait ImgHashBaseTrait: core::AlgorithmTrait {
 	
 }
 
+pub trait ImgHashBaseTrait: core::AlgorithmTrait + crate::img_hash::ImgHashBaseTraitConst {
+	fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void;
+
+	/// Computes hash of the input image
+	/// ## Parameters
+	/// * inputArr: input image want to compute hash value
+	/// * outputArr: hash of the image
+	fn compute(&mut self, input_arr: &dyn core::ToInputArray, output_arr: &mut dyn core::ToOutputArray) -> Result<()> {
+		input_array_arg!(input_arr);
+		output_array_arg!(output_arr);
+		unsafe { sys::cv_img_hash_ImgHashBase_compute_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ImgHashBase(), input_arr.as_raw__InputArray(), output_arr.as_raw__OutputArray()) }.into_result()
+	}
+	
+}
+
 /// The base class for image hash algorithms
 pub struct ImgHashBase {
 	ptr: *mut c_void
@@ -402,20 +430,21 @@ impl Drop for ImgHashBase {
 	}
 }
 
-impl ImgHashBase {
-	#[inline] pub fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for ImgHashBase {}
 
-impl core::AlgorithmTrait for ImgHashBase {
+impl core::AlgorithmTraitConst for ImgHashBase {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for ImgHashBase {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for ImgHashBase {
+impl crate::img_hash::ImgHashBaseTraitConst for ImgHashBase {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for ImgHashBase {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
@@ -427,9 +456,8 @@ boxed_cast_base! { ImgHashBase, core::Algorithm, cv_ImgHashBase_to_Algorithm }
 /// Marr-Hildreth Operator Based Hash, slowest but more discriminative.
 /// 
 /// See [zauner2010implementation](https://docs.opencv.org/4.5.3/d0/de3/citelist.html#CITEREF_zauner2010implementation) for details.
-pub trait MarrHildrethHashTrait: crate::img_hash::ImgHashBaseTrait {
+pub trait MarrHildrethHashTraitConst: crate::img_hash::ImgHashBaseTraitConst {
 	fn as_raw_MarrHildrethHash(&self) -> *const c_void;
-	fn as_raw_mut_MarrHildrethHash(&mut self) -> *mut c_void;
 
 	/// self explain
 	fn get_alpha(&self) -> Result<f32> {
@@ -441,6 +469,11 @@ pub trait MarrHildrethHashTrait: crate::img_hash::ImgHashBaseTrait {
 		unsafe { sys::cv_img_hash_MarrHildrethHash_getScale_const(self.as_raw_MarrHildrethHash()) }.into_result()
 	}
 	
+}
+
+pub trait MarrHildrethHashTrait: crate::img_hash::ImgHashBaseTrait + crate::img_hash::MarrHildrethHashTraitConst {
+	fn as_raw_mut_MarrHildrethHash(&mut self) -> *mut c_void;
+
 	/// Set Mh kernel parameters
 	/// ## Parameters
 	/// * alpha: int scale factor for marr wavelet (default=2).
@@ -467,25 +500,29 @@ impl Drop for MarrHildrethHash {
 	}
 }
 
-impl MarrHildrethHash {
-	#[inline] pub fn as_raw_MarrHildrethHash(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_MarrHildrethHash(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for MarrHildrethHash {}
 
-impl core::AlgorithmTrait for MarrHildrethHash {
+impl core::AlgorithmTraitConst for MarrHildrethHash {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for MarrHildrethHash {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for MarrHildrethHash {
+impl crate::img_hash::ImgHashBaseTraitConst for MarrHildrethHash {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for MarrHildrethHash {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::MarrHildrethHashTrait for MarrHildrethHash {
+impl crate::img_hash::MarrHildrethHashTraitConst for MarrHildrethHash {
 	#[inline] fn as_raw_MarrHildrethHash(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::MarrHildrethHashTrait for MarrHildrethHash {
 	#[inline] fn as_raw_mut_MarrHildrethHash(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
@@ -497,7 +534,7 @@ impl MarrHildrethHash {
 	/// ## C++ default parameters
 	/// * alpha: 2.0f
 	/// * scale: 1.0f
-	pub fn create(alpha: f32, scale: f32) -> Result<core::Ptr::<crate::img_hash::MarrHildrethHash>> {
+	pub fn create(alpha: f32, scale: f32) -> Result<core::Ptr<crate::img_hash::MarrHildrethHash>> {
 		unsafe { sys::cv_img_hash_MarrHildrethHash_create_float_float(alpha, scale) }.into_result().map(|r| unsafe { core::Ptr::<crate::img_hash::MarrHildrethHash>::opencv_from_extern(r) } )
 	}
 	
@@ -512,8 +549,12 @@ boxed_cast_base! { MarrHildrethHash, crate::img_hash::ImgHashBase, cv_MarrHildre
 /// Slower than average_hash, but tolerant of minor modifications
 /// 
 /// This algorithm can combat more variation than averageHash, for more details please refer to [lookslikeit](https://docs.opencv.org/4.5.3/d0/de3/citelist.html#CITEREF_lookslikeit)
-pub trait PHashTrait: crate::img_hash::ImgHashBaseTrait {
+pub trait PHashTraitConst: crate::img_hash::ImgHashBaseTraitConst {
 	fn as_raw_PHash(&self) -> *const c_void;
+
+}
+
+pub trait PHashTrait: crate::img_hash::ImgHashBaseTrait + crate::img_hash::PHashTraitConst {
 	fn as_raw_mut_PHash(&mut self) -> *mut c_void;
 
 }
@@ -536,30 +577,34 @@ impl Drop for PHash {
 	}
 }
 
-impl PHash {
-	#[inline] pub fn as_raw_PHash(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_PHash(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for PHash {}
 
-impl core::AlgorithmTrait for PHash {
+impl core::AlgorithmTraitConst for PHash {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for PHash {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for PHash {
+impl crate::img_hash::ImgHashBaseTraitConst for PHash {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for PHash {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::PHashTrait for PHash {
+impl crate::img_hash::PHashTraitConst for PHash {
 	#[inline] fn as_raw_PHash(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::PHashTrait for PHash {
 	#[inline] fn as_raw_mut_PHash(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
 impl PHash {
-	pub fn create() -> Result<core::Ptr::<crate::img_hash::PHash>> {
+	pub fn create() -> Result<core::Ptr<crate::img_hash::PHash>> {
 		unsafe { sys::cv_img_hash_PHash_create() }.into_result().map(|r| unsafe { core::Ptr::<crate::img_hash::PHash>::opencv_from_extern(r) } )
 	}
 	
@@ -572,9 +617,8 @@ boxed_cast_base! { PHash, crate::img_hash::ImgHashBase, cv_PHash_to_ImgHashBase
 /// Image hash based on Radon transform.
 /// 
 /// See [tang2012perceptual](https://docs.opencv.org/4.5.3/d0/de3/citelist.html#CITEREF_tang2012perceptual) for details.
-pub trait RadialVarianceHashTrait: crate::img_hash::ImgHashBaseTrait {
+pub trait RadialVarianceHashTraitConst: crate::img_hash::ImgHashBaseTraitConst {
 	fn as_raw_RadialVarianceHash(&self) -> *const c_void;
-	fn as_raw_mut_RadialVarianceHash(&mut self) -> *mut c_void;
 
 	fn get_num_of_angle_line(&self) -> Result<i32> {
 		unsafe { sys::cv_img_hash_RadialVarianceHash_getNumOfAngleLine_const(self.as_raw_RadialVarianceHash()) }.into_result()
@@ -584,6 +628,11 @@ pub trait RadialVarianceHashTrait: crate::img_hash::ImgHashBaseTrait {
 		unsafe { sys::cv_img_hash_RadialVarianceHash_getSigma_const(self.as_raw_RadialVarianceHash()) }.into_result()
 	}
 	
+}
+
+pub trait RadialVarianceHashTrait: crate::img_hash::ImgHashBaseTrait + crate::img_hash::RadialVarianceHashTraitConst {
+	fn as_raw_mut_RadialVarianceHash(&mut self) -> *mut c_void;
+
 	fn set_num_of_angle_line(&mut self, value: i32) -> Result<()> {
 		unsafe { sys::cv_img_hash_RadialVarianceHash_setNumOfAngleLine_int(self.as_raw_mut_RadialVarianceHash(), value) }.into_result()
 	}
@@ -592,7 +641,7 @@ pub trait RadialVarianceHashTrait: crate::img_hash::ImgHashBaseTrait {
 		unsafe { sys::cv_img_hash_RadialVarianceHash_setSigma_double(self.as_raw_mut_RadialVarianceHash(), value) }.into_result()
 	}
 	
-	fn get_features(&mut self) -> Result<core::Vector::<f64>> {
+	fn get_features(&mut self) -> Result<core::Vector<f64>> {
 		unsafe { sys::cv_img_hash_RadialVarianceHash_getFeatures(self.as_raw_mut_RadialVarianceHash()) }.into_result().map(|r| unsafe { core::Vector::<f64>::opencv_from_extern(r) } )
 	}
 	
@@ -626,25 +675,29 @@ impl Drop for RadialVarianceHash {
 	}
 }
 
-impl RadialVarianceHash {
-	#[inline] pub fn as_raw_RadialVarianceHash(&self) -> *const c_void { self.as_raw() }
-	#[inline] pub fn as_raw_mut_RadialVarianceHash(&mut self) -> *mut c_void { self.as_raw_mut() }
-}
-
 unsafe impl Send for RadialVarianceHash {}
 
-impl core::AlgorithmTrait for RadialVarianceHash {
+impl core::AlgorithmTraitConst for RadialVarianceHash {
 	#[inline] fn as_raw_Algorithm(&self) -> *const c_void { self.as_raw() }
+}
+
+impl core::AlgorithmTrait for RadialVarianceHash {
 	#[inline] fn as_raw_mut_Algorithm(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::ImgHashBaseTrait for RadialVarianceHash {
+impl crate::img_hash::ImgHashBaseTraitConst for RadialVarianceHash {
 	#[inline] fn as_raw_ImgHashBase(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::ImgHashBaseTrait for RadialVarianceHash {
 	#[inline] fn as_raw_mut_ImgHashBase(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
-impl crate::img_hash::RadialVarianceHashTrait for RadialVarianceHash {
+impl crate::img_hash::RadialVarianceHashTraitConst for RadialVarianceHash {
 	#[inline] fn as_raw_RadialVarianceHash(&self) -> *const c_void { self.as_raw() }
+}
+
+impl crate::img_hash::RadialVarianceHashTrait for RadialVarianceHash {
 	#[inline] fn as_raw_mut_RadialVarianceHash(&mut self) -> *mut c_void { self.as_raw_mut() }
 }
 
@@ -652,7 +705,7 @@ impl RadialVarianceHash {
 	/// ## C++ default parameters
 	/// * sigma: 1
 	/// * num_of_angle_line: 180
-	pub fn create(sigma: f64, num_of_angle_line: i32) -> Result<core::Ptr::<crate::img_hash::RadialVarianceHash>> {
+	pub fn create(sigma: f64, num_of_angle_line: i32) -> Result<core::Ptr<crate::img_hash::RadialVarianceHash>> {
 		unsafe { sys::cv_img_hash_RadialVarianceHash_create_double_int(sigma, num_of_angle_line) }.into_result().map(|r| unsafe { core::Ptr::<crate::img_hash::RadialVarianceHash>::opencv_from_extern(r) } )
 	}
 	
